@@ -15,14 +15,13 @@
  * @author Michael Goffioul
  */
 
-#ifndef KTNEFPROPERTY_H
-#define KTNEFPROPERTY_H
+#pragma once
 
+#include "ktnef_export.h"
 #include <QString>
 #include <QVariant>
+#include <memory>
 class KTNEFPropertyPrivate;
-#include "ktnef_export.h"
-
 namespace KTnef
 {
 /**
@@ -138,9 +137,8 @@ public:
 
 private:
     //@cond PRIVATE
-    KTNEFPropertyPrivate *const d;
+    std::unique_ptr<KTNEFPropertyPrivate> const d;
     //@endcond
 };
 
 }
-#endif
